# gradle

## Gradle Build Command
```
--detect.gradle.build.command
```

Gradle command line arguments to add to the gradle/gradlew command line\.

By default, Detect runs the gradle \(or gradlew\) command with one task: dependencies\. You can use this property to insert one or more additional gradle command line arguments \(options or tasks\) before the dependencies argument\.

|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Gradle Executable
```
--detect.gradle.path
```

The path to the Gradle executable \(gradle or gradlew\)\.

If set, Detect will use the given Gradle executable instead of searching for one\.

|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional Path|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|


## Gradle Exclude Configurations (Advanced)
```
--detect.gradle.excluded.configurations
```

A comma\-separated list of Gradle configurations to exclude\.

As Detect examines the Gradle project for dependencies, Detect will skip any Gradle configurations specified via this property\. This property accepts filename globbing\-style wildcards\. Refer to the <i>Configuring Synopsys Detect</i> > <i>Property wildcard support</i> page for more details\.

|Details||
|---|---|
|Added|3\.0\.0|
|Type|String List|
|Default Value||
|Comma Separated|Yes|
|Case Sensitive|Yes|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Gradle Exclude Projects (Advanced)
```
--detect.gradle.excluded.projects
```

A comma\-separated list of Gradle sub\-projects to exclude\.

As Detect examines the Gradle project for dependencies, Detect will skip any Gradle sub\-projects specified via this property\. This property accepts filename globbing\-style wildcards\. Refer to the <i>Configuring Synopsys Detect</i> > <i>Property wildcard support</i> page for more details\.

|Details||
|---|---|
|Added|3\.0\.0|
|Type|String List|
|Default Value||
|Comma Separated|Yes|
|Case Sensitive|Yes|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Gradle Include Configurations (Advanced)
```
--detect.gradle.included.configurations
```

A comma\-separated list of Gradle configurations to include\.

As Detect examines the Gradle project for dependencies, if this property is set, Detect will include only those Gradle configurations specified via this property that are not excluded\. Leaving this unset implies 'include all'\. Exclusion rules always win\. This property accepts filename globbing\-style wildcards\. Refer to the <i>Configuring Synopsys Detect</i> > <i>Property wildcard support</i> page for more details\.

|Details||
|---|---|
|Added|3\.0\.0|
|Type|String List|
|Default Value||
|Comma Separated|Yes|
|Case Sensitive|Yes|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Gradle Include Unresolved Configurations (Advanced)
```
--detect.gradle.include.unresolved.configurations=false
```

When set to true, dependencies discovered from unresolved Gradle configurations will be included\. It is set to false by default for a more accurate BOM\.

Including dependencies from unresolved Gradle configurations could lead to false positives\. Dependency versions from an unresolved configuration may differ from a resolved one\. See https://docs\.gradle\.org/7\.2/userguide/declaring\_dependencies\.html\#sec:resolvable\-consumable\-configs

|Details||
|---|---|
|Added|7\.6\.0|
|Type|Boolean|
|Default Value|false|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|``|

## Gradle Include Projects (Advanced)
```
--detect.gradle.included.projects
```

A comma\-separated list of Gradle sub\-projects to include\.

As Detect examines the Gradle project for dependencies, if this property is set, Detect will include only those sub\-projects specified via this property that are not excluded\. Leaving this unset implies 'include all'\. Exclusion rules always win\. This property accepts filename globbing\-style wildcards\. Refer to the <i>Configuring Synopsys Detect</i> > <i>Property wildcard support</i> page for more details\.

|Details||
|---|---|
|Added|3\.0\.0|
|Type|String List|
|Default Value||
|Comma Separated|Yes|
|Case Sensitive|Yes|
|Acceptable Values|Any|
|Strict|No|
|Example|``|



## Gradle Inspector Version (Deprecated) 
```
--detect.gradle.inspector.version
```

The version of the Gradle Inspector that Detect should use\. By default, Detect will try to automatically determine the correct Gradle Inspector version\.

The Detect Gradle detector uses a separate program, the Gradle Inspector, to discover dependencies from Gradle projects\. Detect automatically downloads the Gradle Inspector as needed\. Use the property to use a specific version of the Gradle Inspector\.

**DEPRECATED: This property is being removed because it no longer provides functionality\. The gradle inspector library is no longer used to gather Gradle dependencies\. The init script generated by Detect has all the necessary functionality\. It will be removed in 8\.0\.0.**

|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

